class RayaApplicationBase():


    async def sleep(self, sleep_time: float):
    	pass

    async def enable_controller(self, ctlr_name: str) -> BaseController:
    	pass

    def finish_app(self):
    	pass

